"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const transformer_1 = __importDefault(require("./transformer"));
const micromatch_1 = __importDefault(require("micromatch"));
const taskFunction = async ({ options, taskUtil, workspace }) => {
    const config = {
        include: ['**/*.js'],
        exclude: [],
        babelConfig: {
            presets: ['@babel/preset-env'],
            sourceMaps: 'inline'
        },
        iife: true,
        forceExtension: false,
        ...options.configuration
    };
    const transformer = new transformer_1.default(config.babelConfig, config.iife);
    const reader = taskUtil.resourceFactory.createFilterReader({
        reader: workspace,
        callback: r => micromatch_1.default.isMatch(r.getPath(), config.include, { ignore: config.exclude })
    });
    const resources = await reader.byGlob(config.include);
    await Promise.all(resources.map(async (resource) => {
        const contents = await resource.getString();
        const transformed = await transformer.transform(contents, resource.getPath());
        const file = taskUtil.resourceFactory.createResource({ path: resource.getPath(), string: transformed });
        const [path, ext] = (0, utils_1.splitPathExtension)(resource.getPath());
        if (config.forceExtension && ext !== config.forceExtension) {
            file.setPath(path + '.' + config.forceExtension);
            taskUtil.setTag(resource, taskUtil.STANDARD_TAGS.OmitFromBuildResult);
        }
        await workspace.write(file, { drain: true });
    }));
};
const determineRequiredDependencies = async ({ availableDependencies, getProject }) => {
    availableDependencies.forEach(name => getProject(name).isFrameworkProject() && availableDependencies.delete(name));
    return availableDependencies;
};
module.exports = taskFunction;
module.exports.determineRequiredDependencies = determineRequiredDependencies;
//# sourceMappingURL=task.js.map