"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRealPath = exports.splitPathExtension = void 0;
const path_1 = require("path");
/**
 * Splits filename/path and extension into tupel
 * @param fileName Path to be handled
 * @returns path and extension in a tupel
 */
function splitPathExtension(fileName) {
    const i = fileName.lastIndexOf('.');
    return [fileName.substring(0, i), fileName.substring(i + 1)];
}
exports.splitPathExtension = splitPathExtension;
/**
 * Gets the real path for a given ui5 resource path
 *
 * @example
 * // Relative
 * "/resources/my/namespace/file.ext" => "/file.ext"
 * // Absolute
 * "/resources/my/namespace/file.ext" => "C:/Documents/ui5-project/webapp/file.ext"
 *
 * @param path Path given by ui5
 * @param project Project interface
 * @param absolute if the new path should be absolute
 * @returns The real path
 */
function getRealPath(path, project, absolute = false) {
    const root = project.getSourcePath();
    const prefix = '/resources/';
    const namespace = project.getNamespace() ?? '';
    let newPath = path;
    if (newPath.startsWith(prefix))
        newPath = newPath.substring(prefix.length);
    if (newPath.startsWith(namespace))
        newPath = newPath.substring(namespace.length);
    return absolute ? (0, path_1.join)(root, newPath) : newPath;
}
exports.getRealPath = getRealPath;
//# sourceMappingURL=utils.js.map